"""
Security analysis package for NeuroSync encryption schemes.
"""

from NeuroSync.security.checks import (
    check_leakage,
    check_diversity,
    check_repetition,
    check_key_sensitivity,
    check_total,
)
from NeuroSync.security.analyzer import SecurityAnalyzer, SecurityReport
from NeuroSync.security.thresholds import SecurityThresholds, SecurityStatus

__all__ = [
    "check_leakage",
    "check_diversity",
    "check_repetition",
    "check_key_sensitivity",
    "check_total",
    "SecurityAnalyzer",
    "SecurityReport",
    "SecurityThresholds",
    "SecurityStatus",
]